@@ -1,18 +1,20 @@
 from typing import Any, Dict, Type
-from .base import AlgoBase, DataGenerator
+
 from .awac import AWAC
 from .awr import AWR, DiscreteAWR
+from .base import AlgoBase
 from .bc import BC, DiscreteBC
 from .bcq import BCQ, DiscreteBCQ
 from .bear import BEAR
 from .cql import CQL, DiscreteCQL
+from .crr import CRR
 from .ddpg import DDPG
 from .dqn import DQN, DoubleDQN
+from .mopo import MOPO
 from .plas import PLAS, PLASWithPerturbation
 from .sac import SAC, DiscreteSAC
 from .td3 import TD3
 
-
 __all__ = [
     "AlgoBase",
     "AWAC",
@@ -25,15 +27,16 @@ __all__ = [
     "BEAR",
     "CQL",
     "DiscreteCQL",
+    "CRR",
     "DDPG",
     "DQN",
     "DoubleDQN",
+    "MOPO",
     "PLAS",
     "PLASWithPerturbation",
     "SAC",
     "DiscreteSAC",
     "TD3",
-    "DataGenerator",
     "get_algo",
     "create_algo",
 ]
@@ -56,9 +59,11 @@ CONTINUOUS_ALGORITHMS: Dict[str, Type[AlgoBase]] = {
     "bcq": BCQ,
     "bear": BEAR,
     "cql": CQL,
+    "crr": CRR,
     "ddpg": DDPG,
-    "sac": SAC,
+    "mopo": MOPO,
     "plas": PLASWithPerturbation,
+    "sac": SAC,
     "td3": TD3,
 }
 
